#ifndef HEADER_OS_EXCEPTION
#define HEADER_OS_EXCEPTION


#include "os/Usings.h"
#include <exception>
#include <array>
#include <cstdint>
#include <cstddef>


namespace os {


/**
 * class that realizes an exception for the objects of namespace os (operating system).
 */
class Exception final : public std::exception
{
public:
	/**
	 * Constructor that generates the corresponding description for the reason.
	 * @param [in] error The error code that is supplied normally by 'errno'.
	 * @param [in] file The path of the file that has thrown this exception.
	 * @param [in] line The line where this exception as been thrown.
	 */
	Exception (const ErrorCode error, const char* file, const std::uint32_t line) noexcept;
	/**
	 * Delivers the message about the reason of this exception.
	 */
	const char* what () const noexcept;

private:
	/**
	 * Max. length for the buffer that contains the reason.
	 */
	static constexpr std::size_t ReasonLength_ = 256;
	/**
	 * The buffer for the reason.
	 */
	std::array<char, ReasonLength_> reason_;
};


} // namespace os


#endif // HEADER_OS_EXCEPTION


#define THROW_OS_EXCEPTION(error) throw os::Exception (error, __FILE__, __LINE__)
