#ifndef HEADER_OS_FILE_LISTER
#define HEADER_OS_FILE_LISTER

#include <vector>
#include <string>
#include <cstdint>

namespace os
{

/**
 * The class delivers a list of all filenames that where found in the directory, which's
 * path where passed to the constructor.
 */
class FileLister
{
public:
	/**
	 * The type of the list
	 */
	using ListType = std::vector<std::string>;

public:
	/**
	 * Constructor that builds up the list.
	 * @param [in] pathDirectory The path of the directory from which the files shall be listed.
	 */
	FileLister(const std::string& pathDirectory);
	/**
	 * Destructor.
	 */
	~FileLister() {}
	FileLister(const FileLister&) = delete;
	FileLister(FileLister&&) = delete;
	FileLister& operator=(const FileLister&) = delete;
	FileLister& operator=(FileLister&&) = delete;
	/**
	 * Supplies the list.
	 */
	const ListType& getList() const noexcept
	{
		return list_;
	}

private:
	/**
	 * The list.
	 */
	ListType list_ {};
};

} // namnespace os

#endif // HEADER_OS_FILE_LISTER
