#ifndef HEADER_OS_FILE_STATUS
#define HEADER_OS_FILE_STATUS

#include <string>
#include <cstdint>
#include <memory>

struct stat;

namespace os
{

/**
 * Class that supplies some status information of a file, whose path is passed to the constructor.
 */
class FileStatus
{
public:
	/**
	 * Constructor the retrieves some status information.
	 * @param [in] path Path of file which is to be retrieved.
	 */
	FileStatus(const std::string& path);
	/**
	 * Destructor.
	 */
	~FileStatus();
	FileStatus(const FileStatus&) = delete;
	FileStatus(FileStatus&&) = delete;
	FileStatus& operator=(const FileStatus&) = delete;
	FileStatus& operator=(FileStatus&&) = delete;
	/**
	 * Returns true, if retrieving was successfully.
	 * @return True, if successful.
	 */
	bool isOk() const noexcept;
	/**
	 * Supplies the size of the file.
	 */
	std::uint64_t getSize() const noexcept;

private:
	/**
	 * Buffer for retrieved information.
	 */
	std::unique_ptr<struct stat> status_;
	/**
	 * Flag that informs about the retrieving.
	 */
	bool isOk_;
};

} // namespace os

#endif // HEADER_OS_FILE_STATUS
