#include "os/Pipe.h"
#include <unistd.h>
#include <fcntl.h>


namespace os
{


	Pipe::Pipe () noexcept
	{
		// do nothing
	}


	Pipe::~Pipe () noexcept
	{
		void (closeInput ());
		void (closeOutput ());
	}


	ErrorCode Pipe::create () noexcept
	{
		return ::pipe2 (& fileDescriptors_ [0], O_CLOEXEC);
	}


	ErrorCode Pipe::closeInput () noexcept
	{
		return close (ReadPipeIndex_);
	}


	ErrorCode Pipe::closeOutput () noexcept
	{
		return close (WritePipeIndex_);
	}


	ErrorCode Pipe::close (const IndexType index) noexcept
	{
		ErrorCode result {0};
		if (UnusedFileDescriptors_ != fileDescriptors_ [index])
		{
			result = ::close (fileDescriptors_ [index]);
			fileDescriptors_ [index] = UnusedFileDescriptors_;
		}
		return result;
	}


	FileDescriptor Pipe::getInputDescriptor () const noexcept
	{
		return fileDescriptors_ [ReadPipeIndex_];
	}


	FileDescriptor Pipe::getOutputDescriptor () const noexcept
	{
		return fileDescriptors_ [WritePipeIndex_];
	}


} /* namespace os */
