#ifndef HEADER_PROCESS_OUTPUT_SCANNER_LINE
#define HEADER_PROCESS_OUTPUT_SCANNER_LINE

#include "os/ProcessOutputScanner.h"
#include <vector>
#include <string>

namespace os
{

/**
 * Class that specializes a line scanner
 */
class ProcessOutputScannerLine final : public ProcessOutputScanner
{
public:
	/**
	 * The line storage.
	 */
	using LinesType = std::vector<std::string>;

public:
	/**
	 * Constructor.
	 */
	ProcessOutputScannerLine():ProcessOutputScanner(){}
	/**
	 * Destructor.
	 */
	~ProcessOutputScannerLine(){}
	ProcessOutputScannerLine(const ProcessOutputScannerLine&) = delete;
	ProcessOutputScannerLine(ProcessOutputScannerLine&&) = delete;
	ProcessOutputScannerLine& operator=(const ProcessOutputScannerLine&) = delete;
	ProcessOutputScannerLine& operator=(ProcessOutputScannerLine&&) = delete;
	/**
	 * The scanner functor that splits the output into line.
	 */
	void operator()(const std::string& data)
	{
		if (data.empty())
		{
			if (!buffer_.empty())
			{
				lines_.push_back(std::move(buffer_));
			}
		}
		else
		{
			for (char const character : data)
			{
				static constexpr char const carriageReturn {0x0d};
				static constexpr char const lineFeed {0x0a};
				if ((carriageReturn == character) || (lineFeed == character))
				{
					if (!buffer_.empty())
					{
						lines_.push_back(std::move(buffer_));
						buffer_.clear();
					}
				}
				else
				{
					buffer_ += character;
				}
			}
		}
	}
	/**
	 * Supplies the line storage.
	 */
	const LinesType& getLines () const noexcept
	{
		return lines_;
	}

private:
	/**
	 * Buffer for unfinished line.
	 */
	std::string buffer_ {};
	/**
	 * The line storage.
	 */
	LinesType lines_ {};
};

} // namespace os

#endif // HEADER_PROCESS_OUTPUT_SCANNER_LINE
