#include "os/ProcessStatus.h"
#include <sys/types.h>
#include <sys/wait.h>
#include <fcntl.h>
#include <unistd.h>


namespace os
{


	ProcessStatus::ProcessStatus (const ProcessStatusValue status) noexcept
		: status_ {status}
	{
		// do nothing
	}

	ProcessStatus::~ProcessStatus ()
	{
		// do nothing
	}

	ProcessStatus::ProcessStatus (const ProcessStatus& status) noexcept
		: status_ {status.status_}
	{
		// do nothing
	}

	ProcessStatus::ProcessStatus (ProcessStatus&& status) noexcept
		: status_ {status.status_}
	{
		// do nothing
	}

	ProcessStatus& ProcessStatus::operator= (const ProcessStatus& status) noexcept
	{
		status_ = status.status_;
		return *this;
	}

	ProcessStatus& ProcessStatus::operator= (ProcessStatus&& status) noexcept
	{
		status_ = status.status_;
		return *this;
	}

	bool ProcessStatus::isTerminatedNormally () const noexcept
	{
		return WIFEXITED (status_);
	}

	bool ProcessStatus::isTerminatedBySignal () const noexcept
	{
		return WIFSIGNALED (status_);
	}

	ErrorCode ProcessStatus::getExitStatus () const noexcept
	{
		return WEXITSTATUS (status_);
	}

	SignalId ProcessStatus::getTerminatingSignal () const noexcept
	{
		return WTERMSIG (status_);
	}


} /* namespace os */
