#ifndef HEADER_OS_PROCESS_STATUS
#define HEADER_OS_PROCESS_STATUS


#include "os/Usings.h"


namespace os
{

	/**
	 * Class that supplies some information about the terminated child process.
	 */
	class ProcessStatus
	{
	public:
		/**
		 * Constructor.
		 * @param [in] status The status value of the terminated child process.
		 */
		ProcessStatus (const ProcessStatusValue status) noexcept;
		/**
		 * Destructor.
		 */
		~ProcessStatus ();
		/**
		 * Copy constructor.
		 */
		ProcessStatus (const ProcessStatus& status) noexcept;
		/**
		 * Move constructor.
		 */
		ProcessStatus (ProcessStatus&& status) noexcept;
		/**
		 * Copy assignment.
		 */
		ProcessStatus& operator= (const ProcessStatus& status) noexcept;
		/**
		 * Move assignment.
		 */
		ProcessStatus& operator= (ProcessStatus&& status) noexcept;
		/**
		 * Determines if the child process has terminated normally.
		 * @return True, if normal termination.
		 */
		bool isTerminatedNormally () const noexcept;
		/**
		 * Determines if the child process has terminated by signal.
		 * @return True, if terminated by signal.
		 */
		bool isTerminatedBySignal () const noexcept;
		/**
		 * Supplies the exit status.
		 * @return The exit status.
		 */
		ErrorCode getExitStatus () const noexcept;
		/**
		 * Supplies the signal that has terminated the child process.
		 * @return The terminating signal.
		 */
		SignalId getTerminatingSignal () const noexcept;

	private:
		/**
		 * The status value of the terminated child process.
		 */
		ProcessStatusValue status_;
	};


} /* namespace os */


#endif /* HEADER_OS_PROCESS_STATUS */
